@@ -40,10 +40,13 @@ void pygdk_add_constants(PyObject *module, const gchar *strip_prefix);
 extern PyMethodDef pygtk_functions[];
 extern PyMethodDef pygdk_functions[];
 
+PyObject *PyGtkDeprecationWarning;
+
 static struct _PyGtk_FunctionStruct functions = {
     VERSION,
 
     &PyGdkAtom_Type,  PyGdkAtom_New,
+    pygdk_rectangle_from_pyobject,
 };
 
 static void
@@ -67,7 +70,7 @@ python_do_pending_calls(gpointer data)
     }
     pyg_unblock_threads();
 
-    if (quit)
+    if (quit && gtk_main_level() > 0)
 	gtk_main_quit();
     
     return TRUE;
@@ -151,6 +154,10 @@ init_gtk(void)
 			 o=PyCObject_FromVoidPtr(&functions, NULL));
     Py_DECREF(o);
 	
+    PyGtkDeprecationWarning = PyErr_NewException("gtk.GtkDeprecationWarning",
+						 PyExc_DeprecationWarning, NULL);
+    PyDict_SetItemString(d, "DeprecationWarning", PyGtkDeprecationWarning);
+
     stock_ids = gtk_stock_list_ids();
     strcpy(buf, "STOCK_");
     for (cur = stock_ids; cur; cur = stock_ids) {
@@ -183,12 +190,33 @@ init_gtk(void)
 	stock_ids = cur->next;
 	g_slist_free_1(cur);
     }
+    
     /* namespace all the gdk stuff in gtk.gdk ... */
     m = Py_InitModule("gtk.gdk", pygdk_functions);
     d = PyModule_GetDict(m);
 
     pygdk_register_classes(d);
     pygdk_add_constants(m, "GDK_");
+      /* Add predefined atoms */
+#define add_atom(name) PyModule_AddObject(m, #name, PyGdkAtom_New(GDK_##name))
 
+    add_atom(SELECTION_PRIMARY);
+    add_atom(SELECTION_SECONDARY);
+    add_atom(SELECTION_CLIPBOARD);
+    add_atom(TARGET_BITMAP);
+    add_atom(TARGET_COLORMAP);
+    add_atom(TARGET_DRAWABLE);
+    add_atom(TARGET_PIXMAP);
+    add_atom(TARGET_STRING);
+    add_atom(SELECTION_TYPE_ATOM);
+    add_atom(SELECTION_TYPE_BITMAP);
+    add_atom(SELECTION_TYPE_COLORMAP);
+    add_atom(SELECTION_TYPE_DRAWABLE);
+    add_atom(SELECTION_TYPE_INTEGER);
+    add_atom(SELECTION_TYPE_PIXMAP);
+    add_atom(SELECTION_TYPE_WINDOW);
+    add_atom(SELECTION_TYPE_STRING);
+#undef add_atom
+    
     gtk_timeout_add(100, python_do_pending_calls, NULL);
 }
